Title: [148234] trunk/Source/WebCore
Revision
148234
Author
[email protected]
Date
2013-04-11 14:01:07 -0700 (Thu, 11 Apr 2013)

Log Message

Cannot scroll to footer on a page with overflow:hidden on the body
https://bugs.webkit.org/show_bug.cgi?id=114462
-and corresponding-
<rdar://problem/13530042>

Reviewed by Simon Fraser.

Add a new scenario in which we want to overrideHidden -- whenever we are the 
mainFrame and there is a header or footer.

* page/FrameView.cpp:
(WebCore::FrameView::applyOverflowToViewport):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (148233 => 148234)


--- trunk/Source/WebCore/ChangeLog	2013-04-11 20:53:25 UTC (rev 148233)
+++ trunk/Source/WebCore/ChangeLog	2013-04-11 21:01:07 UTC (rev 148234)
@@ -1,3 +1,18 @@
+2013-04-11  Beth Dakin  <[email protected]>
+
+        Cannot scroll to footer on a page with overflow:hidden on the body
+        https://bugs.webkit.org/show_bug.cgi?id=114462
+        -and corresponding-
+        <rdar://problem/13530042>
+
+        Reviewed by Simon Fraser.
+
+        Add a new scenario in which we want to overrideHidden -- whenever we are the 
+        mainFrame and there is a header or footer.
+
+        * page/FrameView.cpp:
+        (WebCore::FrameView::applyOverflowToViewport):
+
 2013-04-11  Commit Queue  <[email protected]>
 
         Unreviewed, rolling out r148034, r148052, r148097, and

Modified: trunk/Source/WebCore/page/FrameView.cpp (148233 => 148234)


--- trunk/Source/WebCore/page/FrameView.cpp	2013-04-11 20:53:25 UTC (rev 148233)
+++ trunk/Source/WebCore/page/FrameView.cpp	2013-04-11 21:01:07 UTC (rev 148234)
@@ -607,9 +607,11 @@
     // use the root element.
 
     // To combat the inability to scroll on a page with overflow:hidden on the root when scaled, disregard hidden when
     // there is a frameScaleFactor that is greater than one on the main frame.
 
-    bool overrideHidden = m_frame->page() && m_frame->page()->mainFrame() == m_frame && m_frame->frameScaleFactor() > 1;
+    bool overrideHidden = (m_frame->page() && m_frame->page()->mainFrame() == m_frame && m_frame->frameScaleFactor() > 1)
+        || (m_frame->page() && m_frame->page()->mainFrame() == m_frame && (headerHeight() || footerHeight()));
 
     EOverflow overflowX = o->style()->overflowX();
     EOverflow overflowY = o->style()->overflowY();
@@ -607,9 +607,11 @@
 
     // To combat the inability to scroll on a page with overflow:hidden on the root when scaled, disregard hidden when
-    // there is a frameScaleFactor that is greater than one on the main frame.
+    // there is a frameScaleFactor that is greater than one on the main frame. Also disregard hidden if there is a
+    // header or footer.
 
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to